# -*- coding: utf-8 -*-
#
# The MIT License (MIT)
#
# Copyright (c) <2013> <Colin Duquesnoy>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
"""
Contains the internal widgets used by the grid widget.
"""
from PyQt4 import QtGui, QtCore


class QColorButton(QtGui.QWidget):
    """
    Simple color button used by the property grid to display a color.

    The widget is a combination of QPushButton and a QLabel layout with a
    QHBoxLayout.
    """

    #: Signal emitted when the color value changed.
    valueChanged = QtCore.pyqtSignal(QtGui.QColor)

    def __getColor(self):
        return self._color

    def __setColor(self, color):
        self._color = color
        self.label.setText(color.name())
        self.button.setStyleSheet("background-color: %s;" % color.name())

    #: Gets/Sets the color to display
    color = QtCore.pyqtProperty(QtGui.QColor, fget=__getColor, fset=__setColor)

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        layout = QtGui.QHBoxLayout()
        layout.setContentsMargins(3, 0, 0, 0)

        self.button = QtGui.QToolButton()
        self.button.clicked.connect(self._show_dlg)
        self._color = QtGui.QColor(255, 255, 255, 255)
        layout.addWidget(self.button)

        self.label = QtGui.QLabel()
        layout.addWidget(self.label)
        layout.setStretch(1, 1)
        self.setLayout(layout)

        self.color = QtGui.QColor("#FFFFFF")

    def _show_dlg(self):
        """
        Slots that executes a QColorDialog when the user click the on the
        button.
        """
        c = QtGui.QColorDialog.getColor(self._color, self)
        if c.isValid():
            self.__setColor(c)
            self.valueChanged.emit(c)
